@@ -122,7 +122,7 @@ void cfg_addaddress(struct cvsd_cfg *cfg,
 
   /* create the name for the socket */
   memset(&hints,0,sizeof(struct addrinfo));
-  hints.ai_flags=AI_PASSIVE;
+  hints.ai_flags=AI_PASSIVE|AI_ADDRCONFIG;
   hints.ai_family=PF_UNSPEC;
   hints.ai_socktype=SOCK_STREAM;
   switch (i=getaddrinfo(node,service,&hints,&(addr->addrs)))
