@@ -15,7 +15,7 @@
    Copyright (C) 1999 Chris Black.
    Copyright (C) 2000 Philippe Kehl.
    Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009,
-                 2010 Arthur de Jong.
+                 2010, 2011 Arthur de Jong.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -124,7 +124,7 @@ static void display_version(FILE *fp)
 {
   fprintf(fp,"%s\n",PACKAGE_STRING);
   fprintf(fp,"Written by Chris Black, Philippe Kehl and Arthur de Jong.\n\n");
-  fprintf(fp,"Copyright (C) 1999-2010 Chris Black, Philippe Kehl and Arthur de Jong.\n"
+  fprintf(fp,"Copyright (C) 1999-2011 Chris Black, Philippe Kehl and Arthur de Jong.\n"
              "This is free software; see the source for copying conditions.  There is NO\n"
              "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n");
 }
@@ -379,8 +379,9 @@ static void listenonaddresses(const struct cvsd_addrs *addrs)
   for (addr=addrs->addrs;addr!=NULL;addr=addr->ai_next)
   {
 
+    /* translate address to name */
     switch (i=getnameinfo(addr->ai_addr,addr->ai_addrlen,
-                          host,80,serv,40,
+                          host,sizeof(host),serv,sizeof(serv),
                           NI_NUMERICHOST|NI_NUMERICSERV)<0)
     {
       case 0:
@@ -388,10 +389,14 @@ static void listenonaddresses(const struct cvsd_addrs *addrs)
                       addr->ai_family,addr->ai_socktype,addr->ai_protocol);
         break;
       case EAI_SYSTEM:
-        log_log(LOG_DEBUG,"debug: getnameinfo() failed: %s",strerror(errno));
+        log_log(LOG_DEBUG,"debug: getnameinfo() failed (ignored): %s",strerror(errno));
+        strcpy(host,"?");
+        strcpy(serv,"?");
         break;
       default:
-        log_log(LOG_DEBUG,"debug: getnameinfo() failed: %s",gai_strerror(i));
+        log_log(LOG_DEBUG,"debug: getnameinfo() failed (ignored): %s",gai_strerror(i));
+        strcpy(host,"?");
+        strcpy(serv,"?");
         break;
     }
 
@@ -470,9 +475,9 @@ static void listenonaddresses(const struct cvsd_addrs *addrs)
     /* bind the socket to the specified port */
     if (bind(sock,addr->ai_addr,addr->ai_addrlen)<0)
     {
-      log_log(LOG_ERR,"bind() failed: %s",strerror(errno));
+      log_log(LOG_ERR,"bind(%s,%s) failed: %s",host,serv,strerror(errno));
       if (close(sock))
-        log_log(LOG_WARNING,"problem closing socket (ignored): %s",strerror(errno));
+        log_log(LOG_WARNING,"problem closing socket: %s",strerror(errno));
       exit(1);
     }
 
@@ -496,20 +501,7 @@ static void listenonaddresses(const struct cvsd_addrs *addrs)
     cvsd_serversockets[cvsd_serversocketnum++]=sock;
 
     /* log stuff */
-    switch (i=getnameinfo(addr->ai_addr,addr->ai_addrlen,
-                          host,80,serv,40,
-                          NI_NUMERICHOST|NI_NUMERICSERV)<0)
-    {
-      case 0:
-        log_log(LOG_INFO,"listening on %s %s",host,serv);
-        break;
-      case EAI_SYSTEM:
-        log_log(LOG_ERR,"getnameinfo() failed (ignored): %s",strerror(errno));
-        break;
-      default:
-        log_log(LOG_ERR,"getnameinfo() failed (ignored): %s",gai_strerror(i));
-        break;
-    }
+    log_log(LOG_INFO,"listening on %s %s",host,serv);
 
     count++;
   } /* next addr */
@@ -553,10 +545,7 @@ static void acceptconnection(const struct cvsd_cfg *cfg)
   if (select(max,&fds,NULL,NULL,NULL)<0)
   {
     if (errno==EINTR)
-    {
-      log_log(LOG_DEBUG,"debug: select() failed (ignored): %s",strerror(errno));
-      return;
-    }
+      return; /* ignore, this happens all the time */
     log_log(LOG_ERR,"select() failed: %s",strerror(errno));
     exit(1);
   }
